/*****************************************************************************
* Filename:          C:\Users\Magician\Desktop\BSB\bsb_project/drivers/my_custom_ip_register_v9_00_a/src/my_custom_ip_register_selftest.c
* Version:           9.00.a
* Description:       Contains a diagnostic self-test function for the my_custom_ip_register driver
* Date:              Sat May 29 12:48:06 2010 (by Create and Import Peripheral Wizard)
*****************************************************************************/


/***************************** Include Files *******************************/

#include "my_custom_ip_register.h"

/************************** Constant Definitions ***************************/


/************************** Variable Definitions ****************************/


/************************** Function Definitions ***************************/

/**
 *
 * Run a self-test on the driver/device. Note this may be a destructive test if
 * resets of the device are performed.
 *
 * If the hardware system is not built correctly, this function may never
 * return to the caller.
 *
 * @param   baseaddr_p is the base address of the MY_CUSTOM_IP_REGISTER instance to be worked on.
 *
 * @return
 *
 *    - XST_SUCCESS   if all self-test code passed
 *    - XST_FAILURE   if any self-test code failed
 *
 * @note    Caching must be turned off for this function to work.
 * @note    Self test may fail if data memory and device are not on the same bus.
 *
 */
XStatus MY_CUSTOM_IP_REGISTER_SelfTest(void * baseaddr_p)
{
  int     Index;
  Xuint32 baseaddr;
  Xuint8  Reg8Value;
  Xuint16 Reg16Value;
  Xuint32 Reg32Value;
  
  /*
   * Check and get the device address
   */
  /*
   * Base Address maybe 0. Up to developer to uncomment line below.
  XASSERT_NONVOID(baseaddr_p != XNULL);
   */
  baseaddr = (Xuint32) baseaddr_p;

  xil_printf("******************************\n\r");
  xil_printf("* User Peripheral Self Test\n\r");
  xil_printf("******************************\n\n\r");

  /*
   * Write to user logic slave module register(s) and read back
   */
  xil_printf("User logic slave module test...\n\r");
  xil_printf("   - write 1 to slave register 0 word 0\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteSlaveReg0(baseaddr, 0, 1);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadSlaveReg0(baseaddr, 0);
  xil_printf("   - read %d from register 0 word 0\n\r", Reg32Value);
  if ( Reg32Value != (Xuint32) 1 )
  {
    xil_printf("   - slave register 0 word 0 write/read failed\n\r");
    return XST_FAILURE;
  }
  xil_printf("   - write 2 to slave register 1 word 0\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteSlaveReg1(baseaddr, 0, 2);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadSlaveReg1(baseaddr, 0);
  xil_printf("   - read %d from register 1 word 0\n\r", Reg32Value);
  if ( Reg32Value != (Xuint32) 2 )
  {
    xil_printf("   - slave register 1 word 0 write/read failed\n\r");
    return XST_FAILURE;
  }
  xil_printf("   - write 3 to slave register 2 word 0\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteSlaveReg2(baseaddr, 0, 3);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadSlaveReg2(baseaddr, 0);
  xil_printf("   - read %d from register 2 word 0\n\r", Reg32Value);
  if ( Reg32Value != (Xuint32) 3 )
  {
    xil_printf("   - slave register 2 word 0 write/read failed\n\r");
    return XST_FAILURE;
  }
  xil_printf("   - write 4 to slave register 3 word 0\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteSlaveReg3(baseaddr, 0, 4);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadSlaveReg3(baseaddr, 0);
  xil_printf("   - read %d from register 3 word 0\n\r", Reg32Value);
  if ( Reg32Value != (Xuint32) 4 )
  {
    xil_printf("   - slave register 3 word 0 write/read failed\n\r");
    return XST_FAILURE;
  }
  xil_printf("   - write 5 to slave register 4 word 0\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteSlaveReg4(baseaddr, 0, 5);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadSlaveReg4(baseaddr, 0);
  xil_printf("   - read %d from register 4 word 0\n\r", Reg32Value);
  if ( Reg32Value != (Xuint32) 5 )
  {
    xil_printf("   - slave register 4 word 0 write/read failed\n\r");
    return XST_FAILURE;
  }
  xil_printf("   - write 6 to slave register 5 word 0\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteSlaveReg5(baseaddr, 0, 6);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadSlaveReg5(baseaddr, 0);
  xil_printf("   - read %d from register 5 word 0\n\r", Reg32Value);
  if ( Reg32Value != (Xuint32) 6 )
  {
    xil_printf("   - slave register 5 word 0 write/read failed\n\r");
    return XST_FAILURE;
  }
  xil_printf("   - slave register write/read passed\n\n\r");

  /*
   * Enable all possible interrupts and clear interrupt status register(s)
   */
  xil_printf("Interrupt controller test...\n\r");
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadReg(baseaddr, MY_CUSTOM_IP_REGISTER_INTR_IPISR_OFFSET);
  xil_printf("   - IP (user logic) interrupt status : 0x%08x\n\r", Reg32Value);
  xil_printf("   - clear IP (user logic) interrupt status register\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteReg(baseaddr, MY_CUSTOM_IP_REGISTER_INTR_IPISR_OFFSET, Reg32Value);
  Reg32Value = MY_CUSTOM_IP_REGISTER_mReadReg(baseaddr, MY_CUSTOM_IP_REGISTER_INTR_DISR_OFFSET);
  xil_printf("   - Device (peripheral) interrupt status : 0x%08x\n\r", Reg32Value);
  xil_printf("   - clear Device (peripheral) interrupt status register\n\r");
  MY_CUSTOM_IP_REGISTER_mWriteReg(baseaddr, MY_CUSTOM_IP_REGISTER_INTR_DISR_OFFSET, Reg32Value);
  xil_printf("   - enable all possible interrupt(s)\n\r");
  MY_CUSTOM_IP_REGISTER_EnableInterrupt(baseaddr_p);
  xil_printf("   - write/read interrupt register passed\n\n\r");

  return XST_SUCCESS;
}
